==> bidmad_flutter_plugin-1.5.1.tar.gz: lib/FlutterBaseNativeAd.dart <==
import 'package:flutter/services.dart';

class FlutterBaseNativeAd {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onFailAdCallback;
  var onClickAdCallback;

  FlutterBaseNativeAd({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('makeNativeAd', {"zoneId":zoneId});
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function(String errorMsg)? onFailAd,
    void Function()? onClickAd
  }) async {
    if(onLoadAd != null) {
      onLoadAdCallback = onLoadAd;
    }
    if(onFailAd != null) {
      onFailAdCallback = onFailAd;
    }
    if(onClickAd != null) {
      onClickAdCallback = onClickAd;
    }
  }

  Future<void> loadWidget() async {
    await _platform.invokeMethod('loadWidget');
  }

  Future<void> removeWidget() async {
    await _platform.invokeMethod('removeWidget');
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    String errorMsg = call.arguments.toString();
    switch(call.method){
      case 'onLoadAd' :
        if(onLoadAdCallback != null) {
          onLoadAdCallback();
        };
        break;
      case 'onFailAd' :
        if(onFailAdCallback != null) {
          onFailAdCallback(errorMsg);
        };
        break;
      case 'onClickAd' :
        if(onClickAdCallback != null) {
          onClickAdCallback();
        }
        break;
      default:
        throw ('method not defined');
    }
  }
}

==> bidmad_flutter_plugin-1.7.2.tar.gz: lib/FlutterBaseNativeAd.dart <==
import 'package:flutter/services.dart';

class FlutterBaseNativeAd {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onFailAdCallback;
  var onClickAdCallback;

  FlutterBaseNativeAd({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> setAdInfo(String zoneId) async {
    return await _platform.invokeMethod('makeNativeAd', {"zoneId": zoneId});
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function(String errorMsg)? onFailAd,
    void Function()? onClickAd
  }) async {
    if(onLoadAd != null) {
      onLoadAdCallback = onLoadAd;
    }
    if(onFailAd != null) {
      onFailAdCallback = onFailAd;
    }
    if(onClickAd != null) {
      onClickAdCallback = onClickAd;
    }
  }

  Future<void> loadWidget() async {
    return await _platform.invokeMethod('loadWidget');
  }

  Future<void> removeWidget() async {
    return await _platform.invokeMethod('removeWidget');
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    String errorMsg = call.arguments.toString();
    switch(call.method){
      case 'onLoadAd' :
        if(onLoadAdCallback != null) {
          onLoadAdCallback();
        }
        break;
      case 'onFailAd' :
        if(onFailAdCallback != null) {
          onFailAdCallback(errorMsg);
        }
        break;
      case 'onClickAd' :
        if(onClickAdCallback != null) {
          onClickAdCallback();
        }
        break;
      default:
        throw ('method not defined');
    }
  }
}
